==> opensaml-xacml-impl-3.3.0-sources.jar: org/opensaml/xacml/ctx/impl/ResponseTypeImplBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xacml.ctx.impl;

import org.opensaml.xacml.XACMLConstants;
import org.opensaml.xacml.ctx.ResponseType;
import org.opensaml.xacml.impl.AbstractXACMLObjectBuilder;

/** Builder for {@link ResponseType} objects. */
public class ResponseTypeImplBuilder extends AbstractXACMLObjectBuilder<ResponseType> {

    /** Constructor. */
    public ResponseTypeImplBuilder() {

    }

    /** {@inheritDoc} */
    public ResponseType buildObject() {
        return buildObject(ResponseType.DEFAULT_ELEMENT_NAME);
    }

    /** {@inheritDoc} */
    public ResponseType buildObject(String namespaceURI, String localName, String namespacePrefix) {
        return new ResponseTypeImpl(namespaceURI, localName, XACMLConstants.XACMLCONTEXT_PREFIX);
    }
}

==> opensaml-xacml-impl-3.4.5-sources.jar: org/opensaml/xacml/ctx/impl/ResponseTypeImplBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xacml.ctx.impl;

import org.opensaml.xacml.XACMLConstants;
import org.opensaml.xacml.ctx.ResponseType;
import org.opensaml.xacml.impl.AbstractXACMLObjectBuilder;

/** Builder for {@link ResponseType} objects. */
public class ResponseTypeImplBuilder extends AbstractXACMLObjectBuilder<ResponseType> {

    /** Constructor. */
    public ResponseTypeImplBuilder() {

    }

    /** {@inheritDoc} */
    public ResponseType buildObject() {
        return buildObject(ResponseType.DEFAULT_ELEMENT_NAME);
    }

    /** {@inheritDoc} */
    public ResponseType buildObject(final String namespaceURI, final String localName, final String namespacePrefix) {
        return new ResponseTypeImpl(namespaceURI, localName, XACMLConstants.XACMLCONTEXT_PREFIX);
    }
}
